Deep learning
=============

This lab should be run as a notebook and saved

Ridge regression
================

There is a snippet that should be inserted to remove the many warnings raised.

Frozen reqs
===========

The versions of the labs are referred to in `source/installation.myst`, `source/labs.rst`. Version built
on `readthedocs` is references in `fix_and_run_notebooks.py`
